@@ -849,10 +849,12 @@ database supports are also valid.
 
 =item "LIKE"
 
-In the case of LIKE, the string is surrounded in % signs.  Yes. this is a bug.
-
 =item "NOT LIKE"
 
+=item "MATCHES"
+
+MATCHES is like LIKE, except it surrounds the value with % signs.
+
 =item "STARTSWITH"
 
 STARTSWITH is like LIKE, except it only appends a % at the end of the string
