@@ -203,8 +203,7 @@ the models added to the SchemaGenerator.
 sub create_table_sql_statements {
     my $self = shift;
 
-    # The sort here is to make it predictable, so that we can write tests.
-    return sort $self->_db_schema->sql( $self->handle->dbh );
+    return $self->_db_schema->sql( $self->handle->dbh );
 }
 
 =head2 create_table_sql_text
@@ -236,6 +235,7 @@ sub _db_schema_table_from_model {
     my @columns    = $model->columns;
 
     my @cols;
+    my @indexes;
 
     for my $column (@columns) {
 
@@ -251,12 +251,17 @@ sub _db_schema_table_from_model {
                 default  => $column->default,
             }
             );
+
+        if ($column->indexed) {
+            push @indexes,[$column->name];
+        }
     }
 
     my $table = DBIx::DBSchema::Table->new(
         {   name        => $table_name,
             primary_key => "id",
             columns     => \@cols,
+            (@indexes) ? (index => DBIx::DBSchema::ColGroup->new(\@indexes)) : ()
         }
     );
 
